@@ -1,5 +1,6 @@
 import os
 import ndjson
+import json
 import numpy as np
 import pandas as pd
 from typing import List
@@ -9,24 +10,36 @@ from dateutil.relativedelta import relativedelta
 from gcsfs import GCSFileSystem
 from google.cloud.storage import Client
 from google.cloud.storage.blob import Blob
-from threading import Thread
 
 class GCSReader():
-    ENV = os.getenv('ENVIRONMENT')
-    GCP_PROJECT = os.getenv("GCP_PROJECT")
-    GOOGLE_APPLICATION_CREDENTIALS = os.getenv('GOOGLE_APPLICATION_CREDENTIALS')
-
-    def __init__(self):
+    def __init__(self,gcp_project: str = None,service_account_info: str = None):
+        """
+            The parameters are optional, if are not using the parameters, make sure that the env variables exists:
+            - GCP_PROJECT
+            - GOOGLE_APPLICATION_CREDENTIALS
+            
+            Parameters
+            ---------------
+            gcp_project (optional): GCP Project
+            service_account_info (optional): That should contain the service_account json string, not the path to it
+        """
+        self.GCP_PROJECT = gcp_project if gcp_project else os.getenv("GCP_PROJECT")
+        self.GOOGLE_APPLICATION_CREDENTIALS = service_account_info \
+            if service_account_info \
+            else json.loads(os.getenv('GOOGLE_APPLICATION_CREDENTIALS','{}'))
+        
         if self.GOOGLE_APPLICATION_CREDENTIALS:
             self.client = Client.from_service_account_info(self.GOOGLE_APPLICATION_CREDENTIALS)
         else:
-            raise ConnectionError("Make sure the env variable \"GOOGLE_APPLICATION_CREDENTIALS\" exists")
+            raise ConnectionError(
+                "Make sure the env variable \"GOOGLE_APPLICATION_CREDENTIALS\" exists or send a value to the parameter service_account_info"
+            )
 
     def _return_blobs(
         self,
         bucket_name: str,
-        prefix:str = None,
-        max_results:int = None,
+        prefix: str = None,
+        max_results: int = None,
         delta_time_kwargs: dict = None
     ) -> List[Blob]:
         bucket = self.client.bucket(bucket_name)
@@ -44,10 +57,10 @@ class GCSReader():
     def read_from_json(
         self,
         bucket_name: str,
-        prefix:str = None,
-        max_results:int = None,
+        prefix: str = None,
+        max_results: int = None,
         delta_time_kwargs: dict = None,
-        return_dataframe: bool=False
+        return_dataframe: bool = False
     ):
         blobs = self._return_blobs(
             bucket_name,
@@ -65,8 +78,8 @@ class GCSReader():
     def read_from_parquet(
         self,
         bucket_name: str,
-        prefix:str = None,
-        max_results:int = None,
+        prefix: str = None,
+        max_results: int = None,
         delta_time_kwargs: dict = None
     ):
         blobs = self._return_blobs(
@@ -87,4 +100,4 @@ class GCSReader():
                 dataframe = pd.concat([dataframe,df],ignore_index=True)
             
         dataframe.replace({np.NaN:None},inplace=True)
-        return dataframe
\ No newline at end of file
+        return dataframe
